==> ktextaddons-1.4.0-x86_64-1.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libKF5TextAddonsWidgets.so )
( cd usr/lib64 ; ln -sf libKF5TextAddonsWidgets.so.1 libKF5TextAddonsWidgets.so )
( cd usr/lib64 ; rm -rf libKF5TextAddonsWidgets.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextAddonsWidgets.so.1.4.0 libKF5TextAddonsWidgets.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextAutoCorrectionCore.so )
( cd usr/lib64 ; ln -sf libKF5TextAutoCorrectionCore.so.1 libKF5TextAutoCorrectionCore.so )
( cd usr/lib64 ; rm -rf libKF5TextAutoCorrectionCore.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextAutoCorrectionCore.so.1.4.0 libKF5TextAutoCorrectionCore.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextAutoCorrectionWidgets.so )
( cd usr/lib64 ; ln -sf libKF5TextAutoCorrectionWidgets.so.1 libKF5TextAutoCorrectionWidgets.so )
( cd usr/lib64 ; rm -rf libKF5TextAutoCorrectionWidgets.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextAutoCorrectionWidgets.so.1.4.0 libKF5TextAutoCorrectionWidgets.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextEditTextToSpeech.so )
( cd usr/lib64 ; ln -sf libKF5TextEditTextToSpeech.so.1 libKF5TextEditTextToSpeech.so )
( cd usr/lib64 ; rm -rf libKF5TextEditTextToSpeech.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextEditTextToSpeech.so.1.4.0 libKF5TextEditTextToSpeech.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextEmoticonsCore.so )
( cd usr/lib64 ; ln -sf libKF5TextEmoticonsCore.so.1 libKF5TextEmoticonsCore.so )
( cd usr/lib64 ; rm -rf libKF5TextEmoticonsCore.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextEmoticonsCore.so.1.4.0 libKF5TextEmoticonsCore.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextEmoticonsWidgets.so )
( cd usr/lib64 ; ln -sf libKF5TextEmoticonsWidgets.so.1 libKF5TextEmoticonsWidgets.so )
( cd usr/lib64 ; rm -rf libKF5TextEmoticonsWidgets.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextEmoticonsWidgets.so.1.4.0 libKF5TextEmoticonsWidgets.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextGrammarCheck.so )
( cd usr/lib64 ; ln -sf libKF5TextGrammarCheck.so.1 libKF5TextGrammarCheck.so )
( cd usr/lib64 ; rm -rf libKF5TextGrammarCheck.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextGrammarCheck.so.1.4.0 libKF5TextGrammarCheck.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextTranslator.so )
( cd usr/lib64 ; ln -sf libKF5TextTranslator.so.1 libKF5TextTranslator.so )
( cd usr/lib64 ; rm -rf libKF5TextTranslator.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextTranslator.so.1.4.0 libKF5TextTranslator.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextUtils.so )
( cd usr/lib64 ; ln -sf libKF5TextUtils.so.1 libKF5TextUtils.so )
( cd usr/lib64 ; rm -rf libKF5TextUtils.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextUtils.so.1.4.0 libKF5TextUtils.so.1 )

==> ktextaddons-1.5.0-x86_64-1.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libKF5TextAddonsWidgets.so )
( cd usr/lib64 ; ln -sf libKF5TextAddonsWidgets.so.1 libKF5TextAddonsWidgets.so )
( cd usr/lib64 ; rm -rf libKF5TextAddonsWidgets.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextAddonsWidgets.so.1.5.0 libKF5TextAddonsWidgets.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextAutoCorrectionCore.so )
( cd usr/lib64 ; ln -sf libKF5TextAutoCorrectionCore.so.1 libKF5TextAutoCorrectionCore.so )
( cd usr/lib64 ; rm -rf libKF5TextAutoCorrectionCore.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextAutoCorrectionCore.so.1.5.0 libKF5TextAutoCorrectionCore.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextAutoCorrectionWidgets.so )
( cd usr/lib64 ; ln -sf libKF5TextAutoCorrectionWidgets.so.1 libKF5TextAutoCorrectionWidgets.so )
( cd usr/lib64 ; rm -rf libKF5TextAutoCorrectionWidgets.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextAutoCorrectionWidgets.so.1.5.0 libKF5TextAutoCorrectionWidgets.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextCustomEditor.so )
( cd usr/lib64 ; ln -sf libKF5TextCustomEditor.so.1 libKF5TextCustomEditor.so )
( cd usr/lib64 ; rm -rf libKF5TextCustomEditor.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextCustomEditor.so.1.5.0 libKF5TextCustomEditor.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextEditTextToSpeech.so )
( cd usr/lib64 ; ln -sf libKF5TextEditTextToSpeech.so.1 libKF5TextEditTextToSpeech.so )
( cd usr/lib64 ; rm -rf libKF5TextEditTextToSpeech.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextEditTextToSpeech.so.1.5.0 libKF5TextEditTextToSpeech.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextEmoticonsCore.so )
( cd usr/lib64 ; ln -sf libKF5TextEmoticonsCore.so.1 libKF5TextEmoticonsCore.so )
( cd usr/lib64 ; rm -rf libKF5TextEmoticonsCore.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextEmoticonsCore.so.1.5.0 libKF5TextEmoticonsCore.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextEmoticonsWidgets.so )
( cd usr/lib64 ; ln -sf libKF5TextEmoticonsWidgets.so.1 libKF5TextEmoticonsWidgets.so )
( cd usr/lib64 ; rm -rf libKF5TextEmoticonsWidgets.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextEmoticonsWidgets.so.1.5.0 libKF5TextEmoticonsWidgets.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextGrammarCheck.so )
( cd usr/lib64 ; ln -sf libKF5TextGrammarCheck.so.1 libKF5TextGrammarCheck.so )
( cd usr/lib64 ; rm -rf libKF5TextGrammarCheck.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextGrammarCheck.so.1.5.0 libKF5TextGrammarCheck.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextTranslator.so )
( cd usr/lib64 ; ln -sf libKF5TextTranslator.so.1 libKF5TextTranslator.so )
( cd usr/lib64 ; rm -rf libKF5TextTranslator.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextTranslator.so.1.5.0 libKF5TextTranslator.so.1 )
( cd usr/lib64 ; rm -rf libKF5TextUtils.so )
( cd usr/lib64 ; ln -sf libKF5TextUtils.so.1 libKF5TextUtils.so )
( cd usr/lib64 ; rm -rf libKF5TextUtils.so.1 )
( cd usr/lib64 ; ln -sf libKF5TextUtils.so.1.5.0 libKF5TextUtils.so.1 )
